# Example Package

Serving as a skeleton for a real one.

```
import random_container_with_url_info

print(random_container_with_url_info.data.not_specific_poi_website_list())
```

# Installation

`pip install random_container_with_url_info`

It is uploaded to [pypi.org](https://pypi.org/project/random_container_with_url_info/)

# Run tests

```
python3 -m unittest
```
